pub struct RepStar<A> { /* private fields */ }Trait Implementations
Sourceimpl<A: Parser> Parser for RepStar<A>
impl<A: Parser> Parser for RepStar<A>
type Out = Vec<<A as Parser>::Out>
fn parse<'a>(&self, i: &LCChars<'a>) -> ParseRes<'a, Self::Out>
fn expected(&self) -> Expected
fn parse_s<'a>(&self, s: &'a str) -> Result<Self::Out, PErr<'a>>
fn parse_sn<'a>(&self, s: &'a str) -> Result<(&'a str, Self::Out), PErr<'a>>
Sourcefn then<P: Parser<Out = V2>, V2>(self, b: P) -> Then<Self, P>
fn then<P: Parser<Out = V2>, V2>(self, b: P) -> Then<Self, P>
returns a parser that will combine the results of this and the given parser
into a tuple
Sourcefn then_ig<P: Parser<Out = V2>, V2>(self, b: P) -> ThenIg<Self, P>
fn then_ig<P: Parser<Out = V2>, V2>(self, b: P) -> ThenIg<Self, P>
returns a Parser that will require the given parser completes, but ignores its result
useful for dropping brackets and whitespace
Sourcefn ig_then<P: Parser<Out = V2>, V2>(self, b: P) -> IgThen<Self, P>
fn ig_then<P: Parser<Out = V2>, V2>(self, b: P) -> IgThen<Self, P>
returns a Parser that will require this parser completes, but only return the
result of the given parser
useful for dropping brackets and whitespace etc
Sourcefn or<P: Parser<Out = Self::Out>>(self, p: P) -> Or<Self, P>
fn or<P: Parser<Out = Self::Out>>(self, p: P) -> Or<Self, P>
Returns a Parser that will try both child parsers, (A first) and return the first successfl
result
Sourcefn map<F: Fn(Self::Out) -> V2, V2>(self, f: F) -> Map<Self, V2, F>
fn map<F: Fn(Self::Out) -> V2, V2>(self, f: F) -> Map<Self, V2, F>
Returns a Parser that converts the result of a successful parse to a different type.
Much like map on iterators and Result
Sourcefn try_map<F: Fn(Self::Out) -> Result<V2, Expected>, V2>(
self,
f: F,
) -> TryMap<Self, V2, F>
fn try_map<F: Fn(Self::Out) -> Result<V2, Expected>, V2>( self, f: F, ) -> TryMap<Self, V2, F>
Returns a Parser that converts the result of a successful parse to a different type.
however the map function can fail and return a result
The Error type should be err::ECode, this does not have line associated. That will
be attacked by the TryMap object
so this will pass that error up correctly
fn asv<R: Clone>(self, r: R) -> As<Self, R>
fn ig(self) -> As<Self, ()>
fn map_exp<F: Fn(Expected) -> Expected>(self, f: F) -> MapExp<Self, F>
fn brk(self) -> Break<Self>
fn pull<'a>(self, s: &'a str) -> PullParser<'a, Self, EOI> ⓘ
fn pull_to<'a, E: Parser>(self, end: E, s: &'a str) -> PullParser<'a, Self, E> ⓘ